/*
 * Copyright (c) 2005-2006 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: ComponentRegistryLoader.java,v 1.9 2006/12/14 00:19:50 sshirasu Exp $
 */
package edu.indiana.extreme.xbaya.component.registry;

import xsul5.MLogger;
import edu.indiana.extreme.xbaya.XBayaEngine;
import edu.indiana.extreme.xbaya.component.gui.ComponentTreeNode;
import edu.indiana.extreme.xbaya.gui.Cancelable;
import edu.indiana.extreme.xbaya.gui.ErrorMessages;
import edu.indiana.extreme.xbaya.gui.WaitDialog;

/**
 * @author Satoshi Shirasuna
 */
public class ComponentRegistryLoader implements Cancelable {

    private static final MLogger logger = MLogger.getLogger();

    private XBayaEngine engine;

    private Thread loadThread;

    private boolean canceled;

    private WaitDialog loadingDialog;

    /**
     * Constructs a MyLeadWorkflowLoader.
     * 
     * @param engine
     */
    public ComponentRegistryLoader(XBayaEngine engine) {
        this.engine = engine;

        this.loadingDialog = new WaitDialog(this, "Loading a Component List.",
                "Loading a Component List. " + "Please wait for a moment.",
                this.engine);
    }

    /**
     * @see edu.indiana.extreme.xbaya.gui.Cancelable#cancel()
     */
    public void cancel() {
        this.canceled = true;
        this.loadThread.interrupt();
    }

    /**
     * Loads the workflow.
     * 
     * @param registry
     * 
     */
    public void load(final ComponentRegistry registry) {
        this.canceled = false;

        this.loadThread = new Thread() {
            @Override
            public void run() {
                runInThread(registry);
            }
        };
        this.loadThread.start();

        // This has to be the last because it blocks when the dialog is modal.
        this.loadingDialog.show();
    }

    /**
     * @param registry
     */
    private void runInThread(ComponentRegistry registry) {
        logger.entering();
        try {
            ComponentTreeNode componentTree = registry.getComponentTree();
            if (this.canceled) {
                return;
            }
            this.engine.getGUI().getComponentSelector().addComponentTree(
                    componentTree);
            this.loadingDialog.hide();
        } catch (ComponentRegistryException e) {
            if (this.canceled) {
                logger.caught(e);
            } else {
                this.loadingDialog.hide();
                this.engine.getErrorWindow().error(
                        ErrorMessages.COMPONENT_LIST_LOAD_ERROR, e);
            }
        } catch (RuntimeException e) {
            if (this.canceled) {
                logger.caught(e);
            } else {
                this.loadingDialog.hide();
                this.engine.getErrorWindow().error(
                        ErrorMessages.COMPONENT_LIST_LOAD_ERROR, e);
            }
        } catch (Error e) {
            this.loadingDialog.hide();
            this.engine.getErrorWindow().error(ErrorMessages.UNEXPECTED_ERROR,
                    e);
        }
    }
}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2005-2006 The Trustees of Indiana University. All rights
 * reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
